# Sentry-Yach

`Sentry` 的 `Yach` 通知插件

## 安装

```bash
pip install sentry-yach
```

## 使用

在 `当前项目` 的所有集成页面找到 `Yach` 插件，启用，并设置 `URL` 和 `Secret Key`

![plugin](https://raw.githubusercontent.com/qingchunyibeifangzongle/sentry-yach/master/docs/images/options.png)

在插件上使用`Test Plugin`进行测试，当配置好相关参数后，在群内会得到如下通知

![plugin](https://raw.githubusercontent.com/qingchunyibeifangzongle/sentry-yach/master/docs/images/yach.png)


点击`detail`按钮，打开异常详情页面。
